<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use App\Models\Region;
use App\Rules\FileTypeValidate;
use Illuminate\Http\Request;

class CityController extends Controller {

    public function index() {
        $slugless_cities = City::where('slug', null)->get();

        foreach($slugless_cities as $city){
            $city->slug = str_replace(" ", "-", strtolower($city->name)).'-'.$city->id;
            $city->save();
        }

        $pageTitle  = 'All Cities';
        //$cities = City::searchable(['name'])->with('region')->withCount('listings')->orderBy('id', 'DESC')->paginate(getPaginate());
        $cities = City::searchable(['name'])
            ->with('region')
            ->withCount('listings')
            ->orderBy('listings_count', 'DESC')  // Order by the count of listings
            ->paginate(getPaginate()
        );
        $regions = Region::orderBy('name', 'asc')->get();
        return view('admin.city.index', compact('pageTitle', 'cities', 'regions'));
    }


    public function store(Request $request, $id = 0) {
        $imageValidation = $id ? 'nullable' : 'required';

        $request->validate([
            'name' => 'required|string|unique:cities,name,' . $id,
            'region' => 'required',
            'image'      => ["$imageValidation", new FileTypeValidate(['jpg', 'jpeg', 'png'])],
        ]);

        if ($id) {
            $city     = City::findOrFail($id);
            $notification = 'City updated successfully';
        } else {
            $city     = new City();
            $notification = 'New city added successfully';
        }

        if ($request->hasFile('image')) {
            try {
                //$city->image = fileUploader($request->image, getFilePath('city'), getFileSize('city'), @$city->image);
                $city->image = fileUploader($request->image, storage_path('app/public/'.'assets/images/city'), getFileSize('city'), @$city->image);
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload city image'];
                return back()->withNotify($notify);
            }
        }

        $city->name = $request->name;
        $city->region_id = $request->region;
        $city->country_id = 82;
        if(!$id){
            //if it's a new city
            $city->slug =  str_replace(" ", "-", strtolower($request->name)).'-'.time();
        }
        $city->is_featured = 0;
        $city->save();
        $notify[] = ['success',  $notification];
        return back()->withNotify($notify);
    }

    public function status($id) {
        return City::changeStatus($id);
    }
    public function feature($id) {
        return City::changeStatus($id, 'is_featured');
    }

    public function get_region_cities($region_id)
    {
        try {
            $cities = City::where('region_id', $region_id)->orderBy('name', 'asc')->get();
            return response()->json(['cities' => $cities]);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }
}
