<?php

namespace App\Http\Controllers\Admin;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\City;
use App\Models\Listing;
use App\Models\ListingImage;
use App\Models\Region;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ListingController extends Controller {
    private $pageTitle;

    public function index(Request $request) {
        $this->pageTitle  = 'All Listings';
        

        if(isset($request->status) && isset($request->search)){

            $pageTitle = $this->pageTitle;
            $listings = Listing::where([['status', $request->status], ['title', 'like', '%' . $request->search . '%']])->with('category', 'city', 'images', 'user')
            ->orderBy('id', 'desc')->paginate(getPaginate());
            return view('admin.listing.index', compact('pageTitle', 'listings'));
            exit();

        }elseif(isset($request->status) && !isset($request->search)){

            $pageTitle = $this->pageTitle;
            $listings = Listing::where('status', $request->status)->with('category', 'city', 'images', 'user')
            ->orderBy('id', 'desc')->paginate(getPaginate());
            return view('admin.listing.index', compact('pageTitle', 'listings'));
            exit();

        }elseif(!isset($request->status) && isset($request->search)){

            $pageTitle = $this->pageTitle;
            $listings = Listing::where('title', 'like', '%' . $request->search . '%')->with('category', 'city', 'images', 'user')
            ->orderBy('id', 'desc')->paginate(getPaginate());
            return view('admin.listing.index', compact('pageTitle', 'listings'));
            exit();

        }else{
            return $this->listingData();
        }
        
    }

    public function pendingListings() {
        $this->pageTitle = 'Pending Listings';
        return $this->listingData('pending');
    }
    public function approvedListings() {
        $this->pageTitle = 'Approved Listings';
        return $this->listingData('approved');
    }
    public function rejectedListings() {
        $this->pageTitle = 'Rejected Listings';
        return $this->listingData('rejected');
    }
    public function disabledListings() {
        $this->pageTitle = 'Disabled Listings';
        return $this->listingData('disabled');
    }

    protected function listingData($scope = null) {
        if ($scope) {
            $listings = Listing::$scope();
        } else {
            $listings = Listing::query();
        }

        $pageTitle = $this->pageTitle;
        $listings = $listings
            ->searchable(['title', 'city:name', 'category:name', 'user:username'])
            ->with('category', 'city', 'images', 'user')
            ->orderBy('id', 'desc')
            ->paginate(getPaginate());


        return view('admin.listing.index', compact('pageTitle', 'listings'));
    }

    public function details($id) {
        $pageTitle     = 'Listing Details';
        $listing      = Listing::with('category', 'city', 'images', 'user')->withCount('reviews')->findOrFail($id);
        $totalApproved = Listing::approved()->where('user_id', $listing->user->id)->count();
        $userPlan      = $listing->user->activePlan ?? $listing->user->currentPlan;
        $users = User::orderBy('username', 'asc')->get();
        return view('admin.listing.details', compact('pageTitle', 'listing', 'userPlan', 'totalApproved', 'users'));
    }

    public function create() {
        $pageTitle     = 'Add New Listing';
        $regions = Region::orderBy('name', 'asc')->get();
        $cities = City::orderBy('name', 'asc')->get();
        $categories = Category::orderBy('name', 'asc')->get();
        return view('admin.listing.form', compact('pageTitle', 'regions', 'cities', 'categories'));
    }

    public function store_admin_listing(Request $request){


        $listing = new listing();
        $notification = 'Listing created successfully';

        $listing->user_id          = 1;
        $listing->listing_id      = getTrx(8);
        $listing->title            = $request->title;
        $listing->description      = $request->description;
        $listing->category_id      = $request->category_id;

        $listing->city_id          = $request->city_id;
        $listing->location         = $request->location;
        $listing->open_time        = $request->open_time;
        $listing->close_time       = $request->close_time;
        $listing->day_off          = $request->day_off ?? [];
        $listing->amenities        = $request->amenities ?? [];
        $listing->tags             = $request->tags ?? [];
        $listing->videos           = $request->videos ?? [];
        $listing->status           = Status::LISTING_PENDING;
        $listing->map              = $request->map;
        $listing->save();
        $this->insertImages($request, $listing);

        $notify[] = ['success', $notification];
        return back()->withNotify($notify);

    }

    public function update_listing_owner(Request $request, $id){

        $request->validate(['user'=>'required|integer']);

        $listing = Listing::find($id);

        $listing->user_id = $request->user;
        $listing->save();

        $notify[] = ['success', 'Listing owner updated'];
        return back()->withNotify($notify);

    }

    public function feature($id) {
        return Listing::changeStatus($id, 'is_featured');
    }

    public function status($id) {
        return Listing::changeStatus($id);
    }

    public function approve($id) {
        $listing         = Listing::pending()->find($id);
        $user             = $listing->user;
        $activePlan = $user->activePlan;

        if (!$activePlan) {
            $notify[] = ['error', 'This user have no active plan now'];
            return back()->withNotify($notify);
        }

        $totalApproved = Listing::approved()->where('user_id', $listing->user_id)->count();

        if (@$totalApproved >=  $activePlan->listings) {
            $notify[] = ['error', 'According to user plan , maximum listings already approved'];
            $notify[] = ['info', 'If the plan wanna approved , please upgrade his/her plan.'];
            return back()->withNotify($notify);
        }

        $listing->status = Status::LISTING_APPROVED;
        $listing->save();

        notify($user, 'LISTING_APPROVED', [
            'title'    => $listing->title,
            'city'    => $listing->city->name,
        ]);

        $notify[] = ['success',  "Listing approved successfully"];
        return back()->withNotify($notify);
    }

    public function reject($id) {
        $listing = Listing::pending()->find($id);
        $user     = User::findOrFail($listing->user_id);

        $listing->status = Status::LISTING_REJECTED;
        $listing->save();

        notify($user, 'LISTING_REJECTED', [
            'title'    => $listing->title,
            'city'    => $listing->city->name,
        ]);

        $notify[] = ['success',  "Listing rejected successfully"];
        return back()->withNotify($notify);
    }

    public function delete(Request $request) {

        $request->validate(['listing_id'=>'required']);
        $listing = Listing::find($request->listing_id);
        $user     = User::findOrFail($listing->user_id);

        $listing->status = Status::LISTING_DELETED;
        $listing->save();

        $listing->delete();

        notify($user, 'LISTING_DELETED', [
            'title'    => $listing->title,
            'city'    => $listing->city->name,
        ]);

        $notify[] = ['success',  "Listing deleted successfully"];
        return back()->withNotify($notify);
    }


    public function approve_listing(Request $request) {
        $listing         = Listing::pending()->find($request->listing_id);
        $user             = $listing->user;
        $activePlan = $user->activePlan;

        if (!$listing) {
            abort(400, 'Only listings in the pending state can be approved');
        }
        
        if (!$activePlan) {
            abort(400, 'User has no active plan');
        }

        $totalApproved = Listing::approved()->where('user_id', $listing->user_id)->count();

        if (@$totalApproved >=  $activePlan->listings) {
            abort(400, 'Listing owner has exceeded maximum number of listings permitted');
        }

        $listing->status = Status::LISTING_APPROVED;
        $listing->save();

        /*notify($user, 'LISTING_APPROVED', [
            'title'    => $listing->title,
            'city'    => $listing->city->name,
        ]);
        */

        $notify[] = ['success',  "Listing approved successfully"];
        return back()->withNotify($notify);
    }

    public function suspend_listing($id) {
        $listing = Listing::approved()->find($id);
        $user     = User::findOrFail($listing->user_id);

        if (!$listing) {
            abort(400, 'Only listings in the approved state can be suspended');
        }

        $listing->status = Status::LISTING_PENDING;
        $listing->save();

        
        notify($user, 'LISTING_REJECTED', [
            'title'    => $listing->title,
            'city'    => $listing->city->name,
        ]);
        

        $notify[] = ['success',  "Listing Suspended"];
        return back()->withNotify($notify);
    }

    public function verify_listing($id) {
        $listing = Listing::find($id);

        if (!$listing) {
            abort(400, 'Listing not found');
        }

        $listing->is_verified = 1;
        $listing->verified_by = Auth::id();
        $listing->save();

        $notify[] = ['success',  "Listing Verified"];
        return back()->withNotify($notify);
    }

    public function unverify_listing($id) {
        $listing = Listing::find($id);

        if (!$listing) {
            abort(400, 'Listing not found');
        }

        $listing->is_verified = 0;
        $listing->verified_by =  Auth::id();
        $listing->save();


        $notify[] = ['success',  "Listing Unverified"];
        return back()->withNotify($notify);
    }

    protected function insertImages($request, $listing) {
        //$path = getFilePath('listing');
        $path = storage_path('app/public/'.'assets/images/listing');
        

        $hasImages = $request->file('images');
        if ($hasImages) {
            $size = getFileSize('listing');
            $images = [];

            if (!file_exists($path)) {
                mkdir($path, 0755, true);
            }

            foreach ($hasImages as $file) {
                try {
                    //$name = fileUploader($file, $path, $size);
                    $name = fileUploader($file, $path);
                    $image        = new ListingImage();
                    $image->listing_id = $listing->id;
                    $image->name = $name;
                    $images[]     = $image;
                } catch (\Exception $exp) {
                    $notify[] = ['error', 'Couldn\'t upload listing images'];
                    return back()->withNotify($notify);
                }
            }
            $listing->images()->saveMany($images);
        }
    }
}
