<?php

namespace App\Http\Controllers\Admin;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Lib\PlanSubscription;
use App\Models\Deposit;
use App\Models\GeneralSetting;
use App\Models\Listing;
use App\Models\NotificationLog;
use App\Models\Plan;
use App\Models\User;
use App\Models\UserPlan;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Users;

class ManageUsersController extends Controller {

    public function allUsers(Request $request) {
        $pageTitle = 'All Users';
        $users = $this->userData();
        $plans = Plan::all();
        if(isset($request->search) && isset($request->status) && isset($request->ev_status) && isset($request->sv_status)){
            //all set
            $users = User::where([['email', 'like', '%'.$request->search.'%'], ['status', $request->status], ['ev', $request->ev_status], ['sv', $request->sv_status]])->orderBy('id', 'desc')->paginate(getPaginate());

        }elseif(isset($request->search) && !isset($request->status) && !isset($request->ev_status) && !isset($request->sv_status)){
            //only email
            $users = User::where('email', 'like', '%'.$request->search.'%')->orderBy('id', 'desc')->paginate(getPaginate());

        }elseif(!isset($request->search) && isset($request->status) && !isset($request->ev_status) && !isset($request->sv_status)){
            //only account status
            $users = User::where('status', $request->status)->orderBy('id', 'desc')->paginate(getPaginate());

        }elseif(!isset($request->search) && !isset($request->status) && isset($request->ev_status) && !isset($request->sv_status)){
            //only ev_status
            $users = User::where('ev', $request->ev_status)->orderBy('id', 'desc')->paginate(getPaginate());

        }elseif(!isset($request->search) && !isset($request->status) && !isset($request->ev_status) && isset($request->sv_status)){
            //only sv_status
            $users = User::where('sv', $request->sv_status)->orderBy('id', 'desc')->paginate(getPaginate());
        }elseif(isset($request->search) && isset($request->status) && !isset($request->ev_status) && !isset($request->sv_status)){
            //email and account status
            $users = User::where([['email', 'like', '%'.$request->search.'%'], ['status', $request->status]])->orderBy('id', 'desc')->paginate(getPaginate());
        }
        return view('admin.users.list', compact('plans', 'pageTitle', 'users'));
    }

    public function activeUsers() {
        $pageTitle = 'Active Users';
        $users = $this->userData('active');
        $plans = Plan::all();
        return view('admin.users.list', compact('plans','pageTitle', 'users'));
    }

    public function bannedUsers() {
        $pageTitle = 'Banned Users';
        $users = $this->userData('banned');
        $plans = Plan::all();
        return view('admin.users.list', compact('plans','pageTitle', 'users'));
    }

    public function emailUnverifiedUsers() {
        $pageTitle = 'Email Unverified Users';
        $users = $this->userData('emailUnverified');
        $plans = Plan::all();
        return view('admin.users.list', compact('plans','pageTitle', 'users'));
    }


    public function emailVerifiedUsers() {
        $pageTitle = 'Email Verified Users';
        $users = $this->userData('emailVerified');
        $plans = Plan::all();
        return view('admin.users.list', compact('pageTitle', 'users', 'plans'));
    }


    public function mobileUnverifiedUsers() {
        $pageTitle = 'Mobile Unverified Users';
        $users = $this->userData('mobileUnverified');
        $plans = Plan::all();
        return view('admin.users.list', compact('pageTitle', 'users', 'plans'));
    }


    public function mobileVerifiedUsers() {
        $pageTitle = 'Mobile Verified Users';
        $users = $this->userData('mobileVerified');
        $plans = Plan::all();
        return view('admin.users.list', compact('pageTitle', 'users', 'plans'));
    }


    public function usersWithBalance() {
        $pageTitle = 'Users with Balance';
        $users = $this->userData('withBalance');
        $plans = Plan::all();
        return view('admin.users.list', compact('pageTitle', 'users', 'plans'));
    }


    protected function userData($scope = null) {
        if ($scope) {
            $users = User::$scope();
        } else {
            $users = User::query();
        }
        return $users->searchable(['username', 'email'])->orderBy('id', 'desc')->paginate(getPaginate());
    }


    public function detail($id) {
        $user             = User::findOrFail($id);
        $pageTitle        = 'User Detail - ' . $user->username;
        $totalListings  = Listing::where('user_id', $user->id)->count();
        $totalDeposit     = Deposit::where('user_id', $user->id)->where('status', Status::PAYMENT_SUCCESS)->sum('amount');
        $countries        = json_decode(file_get_contents(resource_path('views/partials/country.json')));

        $listing['total_approved_listings'] = Listing::where('user_id', $user->id)->approved()->count();
        $listing['total_pending_listings']  = Listing::where('user_id', $user->id)->pending()->count();
        $listing['total_disabled_listings'] = Listing::where('user_id', $user->id)->disabled()->count();

        return view('admin.users.detail', compact('pageTitle', 'user', 'totalListings', 'totalDeposit', 'countries', 'listing'));
    }


    public function update(Request $request, $id) {
        $user = User::findOrFail($id);
        $countryData = json_decode(file_get_contents(resource_path('views/partials/country.json')));
        $countryArray   = (array)$countryData;
        $countries      = implode(',', array_keys($countryArray));

        $countryCode    = $request->country;
        $country        = $countryData->$countryCode->country;
        $dialCode       = $countryData->$countryCode->dial_code;

        $request->validate([
            'firstname' => 'required|string|max:40',
            'lastname' => 'required|string|max:40',
            'email' => 'required|email|string|max:40|unique:users,email,' . $user->id,
            'mobile' => 'required|string|max:40|unique:users,mobile,' . $user->id,
            'country' => 'required|in:' . $countries,
        ]);

        $user->mobile = $dialCode . $request->mobile;
        $user->country_code = $countryCode;
        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;
        $user->email = $request->email;

        $user->address = [
            'address' => $request->address,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => @$country,
        ];

        $user->ev = $request->ev ? Status::VERIFIED : Status::UNVERIFIED;
        $user->sv = $request->sv ? Status::VERIFIED : Status::UNVERIFIED;
        $user->save();

        $notify[] = ['success', 'User details updated successfully'];
        return back()->withNotify($notify);
    }


    public function login($id) {
        Auth::loginUsingId($id);
        return to_route('user.home');
    }

    public function status(Request $request, $id) {
        $user = User::findOrFail($id);
        if ($user->status == Status::USER_ACTIVE) {
            $request->validate([
                'reason' => 'required|string|max:255'
            ]);
            $user->status = Status::USER_BAN;
            $user->ban_reason = $request->reason;
            $notify[] = ['success', 'User banned successfully'];
        } else {
            $user->status = Status::USER_ACTIVE;
            $user->ban_reason = null;
            $notify[] = ['success', 'User unbanned successfully'];
        }
        $user->save();
        return back()->withNotify($notify);
    }


    public function showNotificationSingleForm($id) {
        $user = User::findOrFail($id);
        $general = gs();
        if (!$general->en && !$general->sn) {
            $notify[] = ['warning', 'Notification options are disabled currently'];
            return to_route('admin.users.detail', $user->id)->withNotify($notify);
        }
        $pageTitle = 'Send Notification to ' . $user->username;
        return view('admin.users.notification_single', compact('pageTitle', 'user'));
    }

    public function sendNotificationSingle(Request $request, $id) {
        $request->validate([
            'message' => 'required|string',
            'subject' => 'required|string',
        ]);

        $user = User::findOrFail($id);
        notify($user, 'DEFAULT', [
            'subject' => $request->subject,
            'message' => $request->message,
        ]);
        $notify[] = ['success', 'Notification sent successfully'];
        return back()->withNotify($notify);
    }

    public function showNotificationAllForm() {
        $general = gs();
        if (!$general->en && !$general->sn) {
            $notify[] = ['warning', 'Notification options are disabled currently'];
            return to_route('admin.dashboard')->withNotify($notify);
        }
        $notifyToUser = User::notifyToUser();
        $users = User::active()->count();
        $pageTitle = 'Notification to Verified Users';
        return view('admin.users.notification_all', compact('pageTitle', 'users', 'notifyToUser'));
    }

    public function sendNotificationAll(Request $request) {

        $validator = Validator::make($request->all(), [
            'message'                      => 'required',
            'subject'                      => 'required',
            'start'                        => 'required',
            'batch'                        => 'required',
            'being_sent_to'                => 'required',
            'user'                         => 'required_if:being_sent_to,selectedUsers',
            'number_of_days'               => 'required_if:being_sent_to,notLoginUsers|integer|gte:0',
        ], [
            'number_of_days.required_if'   => "Number of days field is required",
        ]);

        if ($validator->fails()) return response()->json(['error' => $validator->errors()->all()]);

        $scope = $request->being_sent_to;
        $users = User::oldest()->active()->$scope()->skip($request->start)->limit($request->batch)->get();
        foreach ($users as $user) {
            notify($user, 'DEFAULT', [
                'subject' => $request->subject,
                'message' => $request->message,
            ]);
        }
        return response()->json([
            'total_sent' => $users->count(),
        ]);
    }

    public function list() {
        $query = User::active();

        if (request()->search) {
            $query->where(function ($q) {
                $q->where('email', 'like', '%' . request()->search . '%')->orWhere('username', 'like', '%' . request()->search . '%');
            });
        }
        $users = $query->orderBy('id', 'desc')->paginate(getPaginate());
        return response()->json([
            'success' => true,
            'users'   => $users,
            'more'    => $users->hasMorePages()
        ]);
    }

    public function notificationLog($id) {
        $user = User::findOrFail($id);
        $pageTitle = 'Notifications Sent to ' . $user->username;
        $logs = NotificationLog::where('user_id', $id)->with('user')->orderBy('id', 'desc')->paginate(getPaginate());
        return view('admin.reports.notification_history', compact('pageTitle', 'logs', 'user'));
    }


    //this function sets a new plan for a user
    public function giveUserNewPlan(Request $request)
    {

        $request->validate([
            'uid' => 'required',
            'plan_id' => 'required'
        ]);

        $plan = Plan::find($request->plan_id);
        $general = GeneralSetting::first();

        $user = User::find($request->uid);
        if(empty($plan) || empty($user)){
            return redirect()->back();
            exit();
        }

        /*UserPlan::create([
            'user_id' => $request->uid,
            'plan_id' => $plan->id,
            'plan_price' => $plan->monthly_price,
            'listings' => $plan->listings,
            'amenities' => $plan->amenities,
            'images' => $plan->images,
            'videos' => $plan->videos,
            'allow_map' => $plan->map,
            'expired_on' => now()->addDays($general->default_plan_duration),
        ]);*/

        $plan->price = 0;
        $plan->expired_on = now()->addDays($general->default_plan_duration);
        $planSubscription = new PlanSubscription($plan, $user);
        $planSubscription->subscribe();

        $notify[] = ['success',  'A new plan was assigned to '.$request->name];
        return back()->withNotify($notify);
    }

    public function cstm_ban_user(Request $request)
    {
        $user = User::find($request->user_id);

        if(!$user){
            abort(400, 'User not found');
        }

        if($user->status == 0){
            $user -> status = 1;
        }else{
            $user -> status = 0; 
        }

        $user->save();

        return back()->with('success', 'User Status Updated');
    }

    public function generateCertificate($user_id)
    {
        $user = User::find($user_id);
        $data = [
            'name' => $user->firstname.' '.$user->lastname,
            'date' => substr($user->created_at, 0, 10),
            'bg_image' => public_path('/images/certificate_bg_five.jpg')
        ];
        $pdf = PDF::loadView('certificate-template', $data)->setPaper('a4', 'landscape');
        return $pdf->download('certificate.pdf');
    }
}
