<?php

namespace App\Http\Controllers;

use App\Models\City;
use App\Models\Plan;
use App\Models\Listing;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Models\Frontend;
use App\Models\Region;

class FrontController extends Controller {

    public function categories() {
        $pageTitle   = 'All Categories';
        $categories  = Category::active()->countApprovedListing()->orderBy('name', 'asc')->get();
        return view($this->activeTemplate . 'categories', compact('pageTitle', 'categories'));
    }

    public function cities() {
        $pageTitle   = 'All Cities';
        $cities = City::active()->countApprovedListing()->orderBy('name', 'asc')->paginate(getPaginate());
        return view($this->activeTemplate . 'cities', compact('pageTitle', 'cities'));
    }

    public function listings(Request $request) {
        $pageTitle  = "Listings";

        $listings = Listing::approved()
            ->withCount('reviews')
            ->withSum('reviews', 'rating')
            ->whereHas('user.activePlan')
            ->with('category', 'city', 'user.activePlan')
            ->searchable(['tags', 'location'])
            ->searchable(['title', 'description'], true);

        if ($request->category_id) {
            /*
            $listings->whereHas('category', function ($category) use ($request) {
                $category->active()->where('slug', $request->category);
            });
            */

            $listings->whereHas('category', function ($category) use ($request) {
                $category->active()->where('id', $request->category_id);
            });
        }

        if($request->region_id){
            $listings->whereHas('city', function ($city) use ($request) {
                $city->whereHas('region', function ($region) use ($request) {
                    $region->where('id', $request->region_id);
                });
            });
        }

        if ($request->city_id) {
            /*
            $listings->whereHas('city', function ($city) use ($request) {
                $city->active()->where('slug', $request->city);
            });
            */

            $listings->whereHas('city', function ($city) use ($request) {
                $city->active()->where('id', $request->city_id);
            });
        }

        if($request->region_id){

        }

        $listings = $listings->orderBy('id', 'DESC')->paginate(getPaginate(12));

        $categories = Category::active()->get();
        $cities     = City::active()->get();
        $regions = Region::where('status', 1)->orderBy('name', 'asc')->get();

        return view($this->activeTemplate . 'listings', compact('pageTitle', 'listings', 'categories', 'cities', 'regions'));
    }

    public function listingDetail($slug, $id) {
        $pageTitle = 'Listing Details';
        $listing   = Listing::approved()->with('category', 'city', 'images', 'user')->withCount('reviews')->findOrFail($id);
        $plan      = $listing->user->activePlan;

        if (!$plan) {
            abort(404);
        }

        $canReview = false;
        $userId = auth()->id() ?? 0;

        if ($userId && $listing->user_id != $userId) {
            $isExist   = $listing->reviews()->where('user_id', $userId)->exists();
            $canReview = !$isExist;
        }
        $allListing = Listing::approved()->count();
        $categories = Category::active()->hasListings()->withCount('listings')->orderBy('listings_count', 'desc')->limit(10)->get();
        $reviews    = $listing->reviews()->with('user:id,username')->orderBy('id', 'desc')->paginate(getPaginate(5));

        if (request()->ajax()) {
            $reviewData = view($this->activeTemplate . 'partials.reviews', compact('reviews'))->render();
            return response()->json([
                'reviews' => $reviewData,
                'next_page_url' => $reviews->nextPageUrl(),
            ]);
        }

        $seoContents['keywords']           = $listing->tags ?? Frontend::where('data_keys', 'seo.data')->first('data_values')?->data_values->keywords;
        $seoContents['social_title']       = $listing->title;
        $seoContents['description']        = strLimit(strip_tags($listing->description), 200);
        $seoContents['social_description'] = strLimit(strip_tags($listing->description), 150);
        $seoContents['image']              = getImage(getFilePath('listing') . '/' . $listing->display_image, getFileSize('listing'));
        $seoContents['image_size']         = getFileSize('listing');

        return view($this->activeTemplate . 'listing_details',  compact('pageTitle', 'listing', 'categories', 'reviews', 'seoContents', 'canReview', 'allListing'));
    }

    public function pricingPlan() {
        $pageTitle = "Pricing Plan";
        $plans   = Plan::active()->orderBy('monthly_price', 'asc')->get();
        return view($this->activeTemplate . 'plans', compact('pageTitle', 'plans'));
    }
}
