@extends('admin.layouts.app')
@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('Image') | @lang('Name')</th>
                                    <th>@lang('Listings')</th>
                                    <!--<th>@lang('Is Featured')</th>-->
                                    <!--<th>@lang('Status')</th>-->
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($categories as $category)
                                    <tr>
                                        <td>
                                            <span class="d-block avatar avatar--xs">
                                                <img src="{{ getImage(getFilePath('category') . '/' . $category->image, getFileSize('category')) }}">
                                            </span>
                                            {{ __($category->name) }}
                                        </td>

                                        <td>
                                            {{ getAmount($category->listings_count) }}
                                        </td>

                                        <!--<td>
                                            @if ($category->is_featured == Status::YES)
                                                <span class="badge badge--warning"> @lang('Yes')</span>
                                            @else
                                                <span class="badge badge--dark"> @lang('No')</span>
                                            @endif
                                        </td>-->

                                        <!--<td>
                                            @php echo $category->statusBadge; @endphp
                                        </td>-->
                                        @php
                                            $category->image_with_path = getImage(getFilePath('category') . '/' . $category->image, getFileSize('category'));
                                        @endphp
                                        <td>
                                            <div class="d-flex justify-content-end flex-wrap gap-1">
                                                <button class="btn btn-outline--primary editBtn cuModalBtn btn-sm" title="Edit Category" data-modal_title="@lang('Update Category')" data-resource="{{ $category }}">
                                                    <i class="bi bi-pencil-square mx-0"></i>
                                                </button>
                                                @if ($category->status == Status::ENABLE)
                                                    <button class="btn btn-outline--danger btn-sm confirmationBtn" title="Disable Category" data-question="@lang('Are you sure to disable this category?')" data-action="{{ route('admin.category.status', $category->id) }}">
                                                        <i class="bi bi-lightbulb-off-fill mx-0"></i>
                                                    </button>
                                                @else
                                                    <button class="btn btn-outline--success confirmationBtn btn-sm" title="Enable Category" data-question="@lang('Are you sure to enable this category?')" data-action="{{ route('admin.category.status', $category->id) }}">
                                                        <i class="bi bi-lightbulb-fill mx-0"></i>
                                                    </button>
                                                @endif

                                                @if ($category->is_featured == Status::YES)
                                                    <button class="btn btn-outline--warning btn-sm confirmationBtn" title="Unfeature Category" data-question="@lang('Are you sure to unfeature this category?')" data-action="{{ route('admin.category.feature', $category->id) }}">
                                                        <i class="bi bi-star-fill mx-0"></i>
                                                    </button>
                                                @else
                                                    <button class="btn btn-outline--info confirmationBtn btn-sm" title="Feature Category" data-question="@lang('Are you sure to feature this category?')" data-action="{{ route('admin.category.feature', $category->id) }}">
                                                        <i class="bi bi-star mx-0"></i>
                                                    </button>
                                                @endif
                                            </div>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($categories->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($categories) }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    @php
        $categoryImage = getImage(getFilePath('category'), getFileSize('category'));
    @endphp
    <!--Cu Modal -->
    <div class="modal fade" id="cuModal" role="dialog" tabindex="-1">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title"></h5>
                    <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('admin.category.store') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="form-group">
                            <label>@lang('Image')</label>
                            <div class="image-upload">
                                <div class="thumb">
                                    <div class="avatar-preview">
                                        <div class="profilePicPreview" style="background-image: url({{ $categoryImage }})">
                                            <button class="remove-image" type="button"><i class="fa fa-times"></i></button>
                                        </div>
                                    </div>

                                    <div class="avatar-edit">
                                        <input class="profilePicUpload" id="profilePicUpload" name="image" type="file" accept=".png, .jpg, .jpeg">
                                        <label class="bg--success" for="profilePicUpload">@lang('Upload Image')</label>
                                        <small class="mt-2">@lang('Supported files'): <b>@lang('jpeg'), @lang('jpg'), @lang('png').</b>
                                            @lang('Image will be resized into '){{ getFileSize('category') }}@lang('px')
                                        </small>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group">
                            <label>@lang('Name')</label>
                            <input class="form-control" name="name" type="text" required>
                        </div>
                        <div class="form-group">
                            <label>@lang('Slug')</label>
                            <input class="form-control" name="slug" type="text" required>
                        </div>
                    </div>

                    <div class="modal-footer">
                        <button class="btn btn--primary w-100 h-45" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <x-confirmation-modal />
@endsection

@push('breadcrumb-plugins')
    <x-search-form />
    <button class="btn btn-sm btn-outline--primary cuModalBtn" data-modal_title="@lang('Add Category')">
        <i class="las la-plus"></i>@lang('Add New')
    </button>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            $('[name=name]').on('keyup', function() {
                let inputString = $(this).val();
                var slug = createSlug(inputString);
                $('[name=slug]').val(slug);
            })

            function createSlug(inputString) {
                var slug = inputString.toLowerCase()
                    .replace(/[^\w\-]+/g, '-')
                    .replace(/\-+/g, '-')
                    .replace(/^-+|-+$/g, '');
                return slug;
            }

            $('.cuModalBtn').on('click', function() {
                $('#cuModal').find('[name=image]').attr('required', 'required');
                $('#cuModal').find('[name=image]').closest('.form-group').find('label').first().addClass('required');
            });


            $('#cuModal').on('hidden.bs.modal', function() {
                $(this).find('.profilePicPreview').css('background-image', `url('{{ $categoryImage }}')`)
            })

        })(jQuery);
    </script>
@endpush
