@extends('admin.layouts.app')
@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--md table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('Listing')</th>
                                    <th>@lang('Category')</th>
                                    <!--<th>@lang('User')</th>-->
                                    <!--<th>@lang('Is Featured')</th>-->
                                    <th>@lang('Status')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>

                            <tbody>
                                @forelse($listings as $listing)
                                    <tr>

                                        <td class="text-start">
                                            <div class="d-flex flex-wrap justify-content-end justify-content-lg-start">
                                                <span class="avatar avatar--xs me-2">
                                                    <img src="{{ getImage(getFilePath('listing') . '/' . $listing->display_image, getFileSize('listing')) }}">
                                                </span>

                                                <span>
                                                    {{ strLimit(__($listing->title), 40) }}
                                                    <br>
                                                    <a href="{{ route('admin.users.detail', $listing->user->id) }}">{{ $listing->user->firstname }} {{ $listing->user->lastname }}</a>
                                                </span>
                                            </div>
                                        </td>

                                        <td class="">

                                            {{ __($listing->category->name) }}
                                            <br>
                                            <span class="text-muted">
                                                <i class="la la-map-marker-alt"></i>{{ strLimit(__($listing->city->name), 30) }}
                                            </span>
                                        </td>

                                        <!--<td>
                                            <a href="{{ route('admin.users.detail', $listing->user->id) }}">{{ $listing->user->firstname }} {{ $listing->user->lastname }}</a>
                                        </td>-->

                                        <!--<td>
                                            @php  echo  $listing->featuredBadge;  @endphp
                                        </td>-->

                                        <td>
                                            @php  echo  $listing->statusBadge;  @endphp
                                        </td>

                                        <td>
                                            <div class="d-flex justify-content-end flex-wrap gap-1">
                                                <a title="View Details" href="{{ route('admin.listing.details', $listing->id) }}" class="btn btn-outline--primary btn-sm">
                                                    <i class="las la-desktop mx-0"></i>
                                                </a>
                                                @if($listing->status == 0 )
                                                    <button title="Approve"  class="confirmationBtn btn btn-outline--success btn-sm" data-action="{{ route('admin.listing.approve', $listing->id) }}" data-question="@lang('Are you sure to approve this listing')?">
                                                        <i class="bi bi-bookmark-check-fill mx-0"></i>
                                                    </button>
                                                @elseif($listing->status == 1)
                                                    <button title="Suspend"  class="btn btn-outline--warning btn-sm confirmationBtn" data-action="{{ route('admin.listing.suspend_listing', $listing->id) }}" data-question="@lang('Are you sure to suspend this listing')?">
                                                        <i class="bi bi-pause-fill mx-0"></i>
                                                    </button>
                                                @elseif ($listing->status == 2)
                                                    <a title="Rejected Listing" href="#" class="btn btn-outline--secondary btn-sm">
                                                        <i class="bi bi-x-circle mx-0"></i>
                                                    </a>
                                                @elseif ($listing->status == 3)
                                                    <a title="Disabled Listing" href="#" class="btn btn-outline--secondary btn-sm">
                                                        <i class="bi bi-x-circle mx-0"></i>
                                                    </a>
                                                @endif

                                                <!--FEATURED / NOT FEATURED-->
                                                
                                                @if (!($listing->status == Status::LISTING_DISABLED || $listing->status == Status::LISTING_REJECTED))
                                                    @if ($listing->is_featured == Status::YES)
                                                        <button class="btn btn-outline--warning btn-sm confirmationBtn" title="Unfeature Listing" data-question="@lang('Are you sure to unfeature this listing?')" data-action="{{ route('admin.listing.feature', $listing->id) }}">
                                                            <i class="bi bi-star-fill mx-0"></i>
                                                        </button>
                                                    @else
                                                        <button title="Feature Listing" class="btn btn-outline--warning confirmationBtn btn-sm" data-question="@lang('Are you sure to feature this listing?')" data-action="{{ route('admin.listing.feature', $listing->id) }}">
                                                            
                                                            <i class="bi bi-star mx-0"></i>
                                                        </button>
                                                    @endif
                                                @else

                                                <button title="Disabled / Rejected Listing" class="btn btn--secondary ">       
                                                    <i class="bi bi-ban mx-0"></i>
                                                </button>

                                                @endif
                                                <!--FEATURED / NOT FEATURED END-->

                                                @if($listing->is_verified == 0)
                                                    <button title="Mark as Verified"   class="btn btn-outline-primary btn-sm confirmationBtn" data-action="{{ route('admin.listing.verify_listing', $listing->id) }}" data-question="@lang('Are you sure to verify this listing')?">
                                                        <i class="bi bi-patch-check mx-0"></i>
                                                    </button>
                                                @else

                                                    <button title="Unverify"  class="btn btn-outline-primary btn-sm confirmationBtn" data-action="{{ route('admin.listing.unverify_listing', $listing->id) }}" data-question="@lang('Are you sure to unverify this listing')?">
                                                        <i class="bi bi-patch-check-fill mx-0"></i>
                                                    </button>

                                                @endif

                                                <a title="Delete Listing" href="#" class="btn btn-outline--danger btn-sm" onclick="delete_listing({{$listing->id}})">
                                                    <i class="las la-trash mx-0"></i>
                                                </a>

                                            </div>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($listings->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($listings) }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    <x-confirmation-modal />
@endsection
@push('breadcrumb-plugins')
    <x-search-form />
    <a href="{{ route('admin.listing.create') }}" class="btn btn-sm btn-outline--primary h-45">
        <i class="las la-plus"></i>@lang('Add New')
    </a>
@endpush
@push('script')
    <script>
        $('select').on('change', function() {
            let form = $('.listing-filter');
            form.submit();
        });

        function delete_listing(id) {
            // Display a SweetAlert confirmation
            Swal.fire({
                title: 'Are you sure?',
                text: 'You won\'t be able to revert this!',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Yes, delete it!'
            }).then((result) => {
                if (result.isConfirmed) {
                    // User clicked "Yes," proceed with deletion
                    var url = "{{ route('admin.listing.delete') }}";
                    $.ajax({
                        type: 'POST',
                        url: url,
                        data: {
                            '_token': '{{csrf_token()}}',
                            'listing_id': id
                        },
                        success: function(res) {
                            location.reload();
                            //console.log('done');
                        }
                    });
                } else {
                    // User clicked "No" or closed the dialog
                    // You can add additional handling if needed
                }
            });
        }


        function approve_listing(id) {
            // Display a SweetAlert confirmation
            Swal.fire({
                title: 'Approve Listing?',
                text: 'Are you sure you want to approve this listing? ',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Yes, Approve!'
            }).then((result) => {
                if (result.isConfirmed) {
                    // User clicked "Yes," proceed with deletion
                    var url = "{{ route('admin.listing.approve_listing') }}";
                    $.ajax({
                        type: 'POST',
                        url: url,
                        data: {
                            '_token': '{{csrf_token()}}',
                            'listing_id': id
                        },
                        beforeSend: function() {
                            // setting a timeout
                            document.body.style.cursor = 'wait';
                        },
                        success: function(res) {
                            
                            // Display a SweetAlert toast on success
                            Swal.fire({
                                icon: 'success',
                                title: 'Listing Approved!',
                                showConfirmButton: false,
                                timer: 2500
                            }).then(() => {
                                location.reload();
                            });

                        },
                        error: function(xhr, status, error){
                            var errorMessage = xhr.responseJSON.message;
                            // Display the error message using SweetAlert
                            Swal.fire({
                                title: 'Error!',
                                text: errorMessage,
                                icon: 'error',
                            });
                        }
                    });
                } else {
                    // User clicked "No" or closed the dialog
                    
                }
            });
        }


        

    </script>
@endpush
