@extends('admin.layouts.app')
@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('Title')</th>
                                    <th>@lang('Price')</th>
                                    <th>@lang('Listings')</th>
                                    <th>@lang('Images')</th>
                                    <th>@lang('Videos')</th>
                                    <th>@lang('Allow Map')</th>
                                    <!--<th>@lang('Status')</th>-->
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($plans as $plan)
                                    <tr>
                                        <td>{{ strLimit(__($plan->title), 30) }}</td>
                                        <td>
                                            @lang('Monthly'): {{ $general->cur_sym . showAmount($plan->monthly_price) }}
                                            <br>
                                            @lang('Yearly'): {{ $general->cur_sym . showAmount($plan->yearly_price) }}
                                        </td>

                                        <td>{{ $plan->listings }}</td>
                                        <td>{{ $plan->images }}</td>
                                        <td>{{ $plan->videos }}</td>

                                        <td>
                                            @if ($plan->map == Status::YES)
                                                <span class="badge badge--success">@lang('Yes')</span>
                                            @else
                                                <span class="badge badge--warning">@lang('No')</span>
                                            @endif
                                        </td>

                                        <!--<td> @php echo $plan->statusBadge; @endphp </td>-->

                                        <td>
                                            <div class="d-flex justify-content-end flex-wrap gap-1">
                                                <button class="btn btn-outline--primary cuModalBtn btn-sm" title="Edit Plan" data-modal_title="@lang('Update Plan')" data-resource="{{ $plan }}">
                                                <i class="bi bi-pencil-square mx-0"></i>
                                                </button>

                                                @if ($plan->status == Status::ENABLE)
                                                    <button class="btn btn-outline--danger btn-sm confirmationBtn" title="Disable Plan" data-question="@lang('Are you sure to disable this plan?')" data-action="{{ route('admin.plan.status', $plan->id) }}">
                                                    <i class="bi bi-lightbulb-off-fill mx-0"></i>
                                                    </button>
                                                @else
                                                    <button class="btn btn-outline--success confirmationBtn btn-sm" title="Enable Plan" data-question="@lang('Are you sure to enable this plan?')" data-action="{{ route('admin.plan.status', $plan->id) }}">
                                                    <i class="bi bi-lightbulb-fill mx-0"></i>
                                                    </button>
                                                @endif
                                            </div>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($plans->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($plans) }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    <!--Cu Modal -->
    <div class="modal fade" id="cuModal" role="dialog" tabindex="-1">
        <div class="modal-dialog modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title"></h5>
                    <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('admin.plan.store') }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>@lang('Title')</label>
                                    <input class="form-control" name="title" type="text" required>
                                </div>
                            </div>

                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Monthly Price')</label>
                                    <div class="input-group">
                                        <input class="form-control" name="monthly_price" type="number" step="any" required>
                                        <span class="input-group-text">{{ __($general->cur_text) }}</span>
                                    </div>
                                </div>
                            </div>

                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Yearly Price')</label>
                                    <div class="input-group">
                                        <input class="form-control" name="yearly_price" type="number" step="any" required>
                                        <span class="input-group-text">{{ __($general->cur_text) }}</span>
                                    </div>
                                </div>
                            </div>

                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Number of Listings') <i class="la la-info-circle" title="@lang('The number of listings can be added')"></i></label>
                                    <input class="form-control" name="listings" type="number" required>
                                </div>
                            </div>

                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Number of Amenities') <i class="la la-info-circle" title="@lang('The number of amenities can be added per listing')"></i></label>
                                    <input class="form-control" name="amenities" type="number" required>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Number of Images') <i class="la la-info-circle" title="@lang('The number of images can be added per listing')"></i></label>
                                    <input class="form-control" name="images" type="number" required>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>@lang('Number of Videos') <i class="la la-info-circle" title="@lang('The number of videos can be added per listing')"></i></label>
                                    <input class="form-control" name="videos" type="number" required>
                                </div>
                            </div>

                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>@lang('Allow Map')</label>
                                    <input type="checkbox" name="map" data-width="100%" data-height="50" data-size="large" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('Yes')" data-off="@lang('No')">
                                </div>
                            </div>

                        </div>
                    </div>
                    <div class="modal-footer">
                        <button class="btn btn--primary w-100 h-45" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <x-confirmation-modal />
@endsection

@push('breadcrumb-plugins')
    <x-search-form />
    <button class="btn btn-sm btn-outline--primary cuModalBtn" data-modal_title="@lang('Add Plan')">
        <i class="las la-plus"></i>@lang('Add New')
    </button>
@endpush

@push('script')
    <script>
        (function($) {
            'use strict';

            $('.cuModalBtn').on('click', function() {
                let data = $(this).data('resource');
                let cuModal = $('#cuModal');

                if (data && data.map == 1) {
                    cuModal.find('[name=map]').bootstrapToggle("on");
                } else {
                    cuModal.find('[name=map]').bootstrapToggle("off");
                }
            });
        })(jQuery);
    </script>
@endpush
