@extends('admin.layouts.app')
@section('panel')
    <div class="row">
        <div class="col-lg-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">
                    <div class="table-responsive--md  table-responsive">
                        <table class="table table--light style--two">
                            <thead>
                                <tr>
                                    <th>@lang('User')</th>
                                    <th>@lang('Contact')</th>
                                    <th>@lang('Country')</th>
                                    <th>@lang('Joined At')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($users as $user)
                                    <tr>
                                        <td>
                                            <span class="fw-bold">{{ $user->fullname }}</span>
                                            <br>
                                            <span class="small">
                                                <a href="{{ route('admin.users.detail', $user->id) }}"><span>@</span>{{ $user->username }}</a>
                                            </span>
                                        </td>

                                        <td>
                                            {{ $user->email }}<br>{{ $user->mobile }}
                                        </td>
                                        <td>
                                            <span class="fw-bold" title="{{ @$user->address->country }}">{{ $user->country_code }}</span>
                                        </td>

                                        <td>
                                            {{ showDateTime($user->created_at) }} <br> {{ diffForHumans($user->created_at) }}
                                        </td>

                                        <td>
                                            <div class="button--group">
                                                <a href="{{ route('admin.users.detail', $user->id) }}" title="@lang('Details')" class="btn btn-sm btn-outline--primary">
                                                    <i class="las la-desktop mx-0"></i>
                                                </a>
                                                <!--Toggle User Status-->
                                                
                                                @if ($user->status == Status::USER_ACTIVE)
                                                    <button type="button" title="Ban User" class="btn btn-outline--danger btn-sm " onclick="show_ban_modal({{ $user->id }})">
                                                        <i class="bi bi-lightbulb-off-fill mx-0"></i>
                                                    </button>
                                                @else
                                                    <button type="button" title="Unban User" class="btn btn-outline--success  btn-sm " onclick="show_ban_modal({{ $user->id }})">
                                                        <i class="bi bi-lightbulb-fill mx-0"></i>
                                                    </button>
                                                @endif

                                                <!--End of Toggle User Status-->
                                                
                                                <a href="#" class="btn btn-sm btn-outline--secondary set-plan-btn" title="@lang('Plan')" data-user-name="{{ $user->fullname }}" data-user-id="{{$user->id}}">
                                                    <i class="las la-file-invoice-dollar mx-0"></i>
                                                </a>
                                                
                                            </div>
                                        </td>

                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
                @if ($users->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($users) }}
                    </div>
                @endif
            </div>
        </div>

    </div>
    <!--"set user plan" modal-->
    <div class="modal fade" id="setPlanModal" role="dialog" tabindex="-1">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Set User Plan</h5>
                    <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="{{ route('set.user.plan') }}" method="POST">
                    @csrf
                    <div class="modal-body">
                        <input type="hidden" name="uid" id="sup-user-id">

                        <div class="form-group">
                            <label>@lang('Name')</label>
                            <input class="form-control" name="name" id="sup-user-name" type="text" readonly>
                        </div>

                        <div class="form-group">
                            <label for="">Plan</label>
                            <select name="plan_id" id="" class="form-control">
                                <option value="">Choose a Plan</option>
                                @foreach ($plans as $data)
                                <option value="{{ $data->id }}">{{ $data->title }}</option>
                                @endforeach
                                
                            </select>
                        </div>
                    </div>

                    <div class="modal-footer">
                        <button class="btn btn--primary w-100 h-45" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div id="userStatusModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">
                        @if ($user->status == Status::USER_ACTIVE)
                            <span>@lang('Ban User')</span>
                        @else
                            <span>@lang('Unban User')</span>
                        @endif
                    </h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="" method="POST" id="user-status-form">
                    @csrf
                    <div class="modal-body">
                        @if ($user->status == Status::USER_ACTIVE)
                            <h6 class="mb-2">@lang('If you ban this user he/she won\'t able to access his/her dashboard.')</h6>
                            <div class="form-group">
                                <label>@lang('Reason')</label>
                                <textarea class="form-control" name="reason" rows="4" required></textarea>
                            </div>
                        @else
                            <p><span>@lang('Ban reason was'):</span></p>
                            <p>{{ $user->ban_reason }}</p>
                            <h4 class="text-center mt-3">@lang('Are you sure to unban this user?')</h4>
                        @endif
                    </div>
                    <div class="modal-footer">
                        @if ($user->status == Status::USER_ACTIVE)
                            <button type="submit" class="btn btn--primary h-45 w-100">@lang('Submit')</button>
                        @else
                            <button type="button" class="btn btn--dark" data-bs-dismiss="modal">@lang('No')</button>
                            <button type="submit" class="btn btn--primary">@lang('Yes')</button>
                        @endif
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('breadcrumb-plugins')
    <x-search-form placeholder="Username / Email" />
@endpush

@push('script')
    <script>
        function show_ban_modal(id){
            var url = '/admin/users/status/'+id
            $('#user-status-form').attr('action', url);
            $('#userStatusModal').modal('show');
        }
    </script>
@endpush
