@php
    $content = getContent('registration.content', true);
    $policyPages = getContent('policy_pages.element', false, null, true);
@endphp
@extends($activeTemplate . 'layouts.app')
@section('panel')
    <section class="account login-register bg-img" style="background-image: url({{ getImage('assets/images/frontend/registration/' . @$content->data_values->image, '2250x1500') }});">
        <div class="account-inner">
            <div class="container">
                <div class="row justify-content-center">
                    <div class="col-lg-8">
                        <div class="account-form">
                            <div class="account-form__content mb-4">
                                <a class="account-logo" href="{{ route('home') }}"><img src="{{ getImage('assets/images/logoIcon/logo_dark.png') }}"></a>
                                <h3 class="account-form__title mb-2"> {{ __($content->data_values->register_heading) }}
                                </h3>
                                <p class="account-form__desc"> {{ __($content->data_values->register_subheading) }}</p>
                            </div>

                            <form action="{{ route('user.register') }}" method="POST" class="verify-gcaptcha">
                                @csrf
                                <div class="row">
                                    <div class="col-sm-6 form-group group-two">
                                        <div class="form--group">
                                            <label for="username" class="form--label">@lang('Username')</label>
                                            <input type="text" name="username" class="form--control control-two checkUser" id="username" value="{{ old('username') }}" required>

                                            <small class="text-danger usernameExist"></small>
                                        </div>
                                    </div>
                                    <div class="col-sm-6 form-group group-two">
                                        <div class="form--group">
                                            <label for="email-address" class="form--label">@lang('Email Address') </label>
                                            <input type="text" name="email" class="form--control control-two checkUser" id="email-address" value="{{ old('email') }}" required>
                                        </div>
                                    </div>
                                    <div class="col-sm-6 form-group group-two">
                                        <div class="form--group">
                                            <label for="country-name" class="form--label">@lang('Country')</label>
                                            <select class="form--control control-two" name="country" id="country-name">
                                                @foreach ($countries as $key => $country)
                                                    <option data-mobile_code="{{ $country->dial_code }}" value="{{ $country->country }}" data-code="{{ $key }}">
                                                        {{ __($country->country) }}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>

                                    <div class="col-sm-6 form-group group-two">
                                        <div class="form--group">
                                            <label for="mobile-number" class="form--label">@lang('Mobile Number') </label>
                                            <input type="hidden" name="mobile_code">
                                            <input type="hidden" name="country_code">
                                            <div class="position-relative number">
                                                <span class="fixed-number mobile-code"></span>
                                                <input type="number" name="mobile" class="form--control control-two checkUser" value="{{ old('mobile') }}"id="mobile-number" required>
                                            </div>
                                            <small class="text-danger mobileExist"></small>
                                        </div>
                                    </div>

                                    <div class="col-sm-6 form-group group-two">
                                        <label for="your-password" class="form--label">@lang('Password')</label>
                                        <div class="position-relative">
                                            <input id="your-password" name="password" type="password" class="form-control form--control control-two @if ($general->secure_password) secure-password @endif">
                                            <div class="password-show-hide fas fa-eye toggle-password fa-eye-slash" id="#your-password"></div>
                                        </div>
                                    </div>
                                    <div class="col-sm-6 form-group group-two">
                                        <label for="confirm-password" class="form--label">@lang('Confirm Password')</label>
                                        <div class="position-relative">
                                            <input id="confirm-password" type="password" class="form-control form--control control-two" name="password_confirmation">
                                            <div class="password-show-hide fas fa-eye toggle-password fa-eye-slash" id="#confirm-password"></div>
                                        </div>
                                    </div>

                                    <x-captcha />

                                    @if ($general->agree)
                                        <div class="col-sm-12 form-group group-two">
                                            <input class="form-check-input me-1" type="checkbox" id="agree" @checked(old('agree')) name="agree" required>
                                            <label class="form-check-label" for="agree">@lang('I agree with')</label>

                                            @foreach ($policyPages as $policy)
                                                <a for="agree" href="{{ route('policy.pages', [slug($policy->data_values->title), $policy->id]) }}" target="_blank">{{ __($policy->data_values->title) }}</a>
                                                @if (!$loop->last)
                                                    ,
                                                @endif
                                            @endforeach
                                        </div>
                                    @endif

                                    <div class="col-sm-12 form-group group-two">
                                        <button type="submit" id="recaptcha" class="btn btn--base w-100">@lang('Register')</button>
                                    </div>
                                    <div class="col-sm-12">
                                        <div class="have-account text-center">
                                            <p class="have-account__text">@lang('Already Have An Account?') <a href="{{ route('user.login') }}" class="have-account__link text--base">@lang('Login')</a></p>
                                        </div>
                                    </div>
                                </div>
                            </form>

                            <div class="account-form__content">
                                <div class="account-form__or">@lang('OR')</div>

                                @php
                                    $credentials = $general->socialite_credentials;
                                @endphp
                                @if ($credentials->google->status == Status::ENABLE || $credentials->facebook->status == Status::ENABLE || $credentials->linkedin->status == Status::ENABLE)
                                    <div class="account-form__social-link flex-center">
                                        @if ($credentials->facebook->status == Status::ENABLE)
                                            <a href="{{ route('user.social.login', 'facebook') }}" class="account-form__icon facebook">
                                                <i class="lab la-facebook"></i>
                                            </a>
                                        @endif
                                        @if ($credentials->google->status == Status::ENABLE)
                                            <a href="{{ route('user.social.login', 'google') }}" class="account-form__icon google">
                                                <i class="lab la-google-plus-g"></i>
                                            </a>
                                        @endif
                                        @if ($credentials->linkedin->status == Status::ENABLE)
                                            <a href="{{ route('user.social.login', 'linkedin') }}" class="account-form__icon linkedin">
                                                <i class="lab la-linkedin"></i>
                                            </a>
                                        @endif
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('modal')
    <div class="modal fade" id="existModalCenter" tabindex="-1" role="dialog" aria-labelledby="existModalCenterTitle" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="existModalLongTitle">@lang('You are with us')</h5>
                    <span type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </span>
                </div>
                <div class="modal-body">
                    <h6 class="text-center">@lang('You already have an account please Login ')</h6>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-dark btn--sm" data-bs-dismiss="modal">@lang('Close')</button>
                    <a href="{{ route('user.login') }}" class="btn btn--base btn--sm">@lang('Login')</a>
                </div>
            </div>
        </div>
    </div>
@endpush

@if ($general->secure_password)
    @push('script-lib')
        <script src="{{ asset('assets/global/js/secure_password.js') }}"></script>
    @endpush
@endif

@push('script')
    <script>
        "use strict";
        (function($) {
            @if ($mobileCode)
                $(`option[data-code={{ $mobileCode }}]`).attr('selected', '');
            @endif

            $('select[name=country]').change(function() {
                $('input[name=mobile_code]').val($('select[name=country] :selected').data('mobile_code'));
                $('input[name=country_code]').val($('select[name=country] :selected').data('code'));
                $('.mobile-code').text('+' + $('select[name=country] :selected').data('mobile_code'));
            });
            $('input[name=mobile_code]').val($('select[name=country] :selected').data('mobile_code'));
            $('input[name=country_code]').val($('select[name=country] :selected').data('code'));
            $('.mobile-code').text('+' + $('select[name=country] :selected').data('mobile_code'));

            $('.checkUser').on('focusout', function(e) {
                var url = '{{ route('user.checkUser') }}';
                var value = $(this).val();
                var token = '{{ csrf_token() }}';
                if ($(this).attr('name') == 'mobile') {
                    var mobile = `${$('.mobile-code').text().substr(1)}${value}`;
                    var data = {
                        mobile: mobile,
                        _token: token
                    }
                }
                if ($(this).attr('name') == 'email') {
                    var data = {
                        email: value,
                        _token: token
                    }
                }
                if ($(this).attr('name') == 'username') {
                    var data = {
                        username: value,
                        _token: token
                    }
                }
                $.post(url, data, function(response) {
                    if (response.data != false && response.type == 'email') {
                        $('#existModalCenter').modal('show');
                    } else if (response.data != false) {
                        $(`.${response.type}Exist`).text(`${response.type} already exist`);
                    } else {
                        $(`.${response.type}Exist`).text('');
                    }
                });
            });
        })(jQuery);
    </script>
@endpush
