<?php

use App\Http\Controllers\Admin\CityController;
use App\Http\Controllers\Admin\ManageUsersController;
use App\Models\City;
use App\Models\User;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\Route;

Route::get('/clear', function () {
    \Illuminate\Support\Facades\Artisan::call('optimize:clear');
});

// User Support Ticket
Route::controller('TicketController')->prefix('ticket')->name('ticket.')->group(function () {
    Route::get('/', 'supportTicket')->name('index');
    Route::get('new', 'openSupportTicket')->name('open');
    Route::post('create', 'storeSupportTicket')->name('store');
    Route::get('view/{ticket}', 'viewTicket')->name('view');
    Route::post('reply/{ticket}', 'replyTicket')->name('reply');
    Route::post('close/{ticket}', 'closeTicket')->name('close');
    Route::get('download/{ticket}', 'ticketDownload')->name('download');
});

Route::get('app/deposit/confirm/{hash}', 'Gateway\PaymentController@appDepositConfirm')->name('deposit.app.confirm');


Route::controller('FrontController')->group(function () {
    Route::get('pricing', 'pricingPlan')->name('pricing');
    Route::get('listings', 'listings')->name('listings');
    Route::get('listing/{slug}/{id}', 'listingDetail')->name('listing.details');
    Route::get('categories', 'categories')->name('categories');
    Route::get('cities', 'cities')->name('cities');
});

Route::controller('SiteController')->group(function () {
    Route::get('/contact', 'contact')->name('contact');
    Route::get('/faq', 'faq')->name('faq');
    Route::post('/contact', 'contactSubmit');
    Route::get('/change/{lang?}', 'changeLanguage')->name('lang');

    Route::get('cookie-policy', 'cookiePolicy')->name('cookie.policy');

    Route::get('/cookie/accept', 'cookieAccept')->name('cookie.accept');

    Route::get('blog', 'blogs')->name('blog');
    Route::get('blog/{slug}/{id}', 'blogDetails')->name('blog.details');

    Route::get('policy/{slug}/{id}', 'policyPages')->name('policy.pages');
    Route::get('placeholder-image/{size}', 'placeholderImage')->name('placeholder.image');

    Route::get('/{slug}', 'pages')->name('pages');
    Route::get('/', 'index')->name('home');
});


Route::get('/get_region_cities/{region_id}', [CityController::class, 'get_region_cities']);

// Payment
Route::prefix('payment')->name('payment.')->controller('Gateway\PaymentController')->group(function () {
    Route::any('/', 'deposit')->name('index');
    Route::post('insert', 'depositInsert')->name('insert');
    Route::get('confirm', 'depositConfirm')->name('confirm');
    Route::get('manual', 'manualDepositConfirm')->name('manual.confirm');
    Route::post('manual', 'manualDepositUpdate')->name('manual.update');
});

Route::post('set-user-plan', [ManageUsersController::class, 'giveUserNewPlan'])->name('set.user.plan');


Route::get('user-certificate/{user_id}', function($user_id){
    $user = User::find($user_id);
    $data = [
        'name' => $user->firstname.' '.$user->lastname,
        'date' => substr($user->created_at, 0, 10),
        'bg_image' => public_path('/images/certificate_bg_five.jpg')
    ];
    $pdf = PDF::loadView('certificate-template', $data)->setPaper('a4', 'landscape');
    return $pdf->download('certificate.pdf');
})->name('certificate.download');